# Batch Cloning Gene List

Enter your list of genes (one gene per line):
SPAPB1A10.09 SPBC15D4.01c
Choose a plasmid option:
Provide Addgene Identifier
Upload Plasmid File
Upload Plasmid Sequence File:
Addgene Identifier:
Checking primers:

These primers are used to verify the integration of the marker cassette. Default primers are provided for KanMX6 and NatMX6 cassettes, but you can specify your own primers if using a different marker.

NatMx6
KanMx6
Other
Checking Primer Forward:

Should align with the top strand of the resulting allele, and will produce a PCR product with a primer that aligns with the bottom strand on the right side of the insertion.

Checking Primer Reverse:

Should align with the bottom strand of the resulting allele, and will produce a PCR product with a primer that aligns with the top strand on the left side of the insertion.

Processing request, please wait...